Learn R Programming

PWMEnrich (version 4.8.2)

registerCoresPWMEnrich: Register than PWMEnrich can use parallel CPU cores

Description

Certain functions (like motif scanning) can be parallelized in PWMEnrich. This function registers a number of parallel cores (via core package parallel) to be used in code that can be parallelized. After this function is called, all further PWMEnrich function calls will run in parallel if possible.

Usage

registerCoresPWMEnrich(numCores = NA)

Arguments

numCores
number of cores to use (default to take all cores), or NULL if no parallel execution is to be used

Details

By default parallel execution is turned off. To turn it off after using it, call this function by passing NULL.

Examples

Run this code
## Not run: 
# registerCoresPWMEnrich(4) # use 4 CPU cores in PWMEnrich
# registerCoresPWMEnrich() # use maximal number of CPUs
# registerCoresPWMEnrich(NULL) # do not use parallel execution
# ## End(Not run)

Run the code above in your browser using DataLab